Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'app/models/concerns/taskable.rb')
-rw-r--r--app/models/concerns/taskable.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/app/models/concerns/taskable.rb b/app/models/concerns/taskable.rb
index 904c96b11b3..ee5774d4868 100644
--- a/app/models/concerns/taskable.rb
+++ b/app/models/concerns/taskable.rb
@@ -59,7 +59,7 @@ module Taskable
end
# Return a string that describes the current state of this Taskable's task
# list items, e.g. "12 of 20 tasks completed"
def task_status(short: false)
return '' if description.blank?
@@ -70,7 +70,7 @@ module Taskable
end
sum = tasks.summary
- "#{sum.complete_count}#{prep}#{sum.item_count} #{'task'.pluralize(sum.item_count)}#{completed}"
+ "#{sum.complete_count}#{prep}#{sum.item_count} #{'checklist item'.pluralize(sum.item_count)}#{completed}"
end
# Return a short string that describes the current state of this Taskable's
@@ -59,7 +59,7 @@ module Taskable
end
# Return a string that describes the current state of this Taskable's task
- # list items, e.g. "12 of 20 tasks completed"
+ # list items, e.g. "12 of 20 checklist items completed"
def task_status(short: false)
return '' if description.blank?